@@ -17,6 +17,7 @@ from swh.scheduler.tests.test_scheduler import TestScheduler  # noqa
 # the Flask app used as server in these tests
 @pytest.fixture
 def app(swh_db_scheduler):
+    assert hasattr(server, "scheduler")
     server.scheduler = swh_db_scheduler
     yield server.app
 
@@ -41,24 +42,34 @@ def test_site_map(flask_app_client):
     expected_rules = set(
         "/" + rule
         for rule in (
-            "set_status_tasks",
-            "create_task_type",
-            "get_task_type",
-            "get_task_types",
-            "create_tasks",
-            "disable_tasks",
-            "get_tasks",
-            "search_tasks",
-            "get_task_runs",
-            "peek_ready_tasks",
-            "grab_ready_tasks",
-            "schedule_task_run",
-            "mass_schedule_task_runs",
-            "start_task_run",
-            "end_task_run",
-            "filter_task_to_archive",
-            "delete_archived_tasks",
-            "get_priority_ratios",
+            "lister/get_or_create",
+            "lister/update",
+            "origins/get",
+            "origins/record",
+            "priority_ratios/get",
+            "task/create",
+            "task/delete_archived",
+            "task/disable",
+            "task/filter_for_archive",
+            "task/get",
+            "task/grab_ready",
+            "task/peek_ready",
+            "task/search",
+            "task/set_status",
+            "task_run/end",
+            "task_run/get",
+            "task_run/schedule",
+            "task_run/schedule_one",
+            "task_run/start",
+            "task_type/create",
+            "task_type/get",
+            "task_type/get_all",
         )
     )
     assert rules == expected_rules
+
+
+def test_root(flask_app_client):
+    root = flask_app_client.get("/")
+    assert root.status_code == 200
+    assert b"Software Heritage scheduler RPC server" in root.data
