@@ -10,25 +10,29 @@ from swh.scheduler.utils import create_task_dict
 from swh.scheduler.celery_backend.runner import run_ready_tasks
 
 
-def test_ping(swh_app, celery_session_worker):
-    res = swh_app.send_task("swh.scheduler.tests.tasks.ping")
+def test_ping(swh_scheduler_celery_app, swh_scheduler_celery_worker):
+    res = swh_scheduler_celery_app.send_task("swh.scheduler.tests.tasks.ping")
     assert res
     res.wait()
     assert res.successful()
     assert res.result == "OK"
 
 
-def test_ping_with_kw(swh_app, celery_session_worker):
-    res = swh_app.send_task("swh.scheduler.tests.tasks.ping", kwargs={"a": 1})
+def test_ping_with_kw(swh_scheduler_celery_app, swh_scheduler_celery_worker):
+    res = swh_scheduler_celery_app.send_task(
+        "swh.scheduler.tests.tasks.ping", kwargs={"a": 1}
+    )
     assert res
     res.wait()
     assert res.successful()
     assert res.result == "OK (kw={'a': 1})"
 
 
-def test_multiping(swh_app, celery_session_worker):
+def test_multiping(swh_scheduler_celery_app, swh_scheduler_celery_worker):
     "Test that a task that spawns subtasks (group) works"
-    res = swh_app.send_task("swh.scheduler.tests.tasks.multiping", kwargs={"n": 5})
+    res = swh_scheduler_celery_app.send_task(
+        "swh.scheduler.tests.tasks.multiping", kwargs={"n": 5}
+    )
     assert res
 
     res.wait()
@@ -38,7 +42,7 @@ def test_multiping(swh_app, celery_session_worker):
     # to complete
     promise_id = res.result
     assert promise_id
-    promise = GroupResult.restore(promise_id, app=swh_app)
+    promise = GroupResult.restore(promise_id, app=swh_scheduler_celery_app)
     for i in range(5):
         if promise.ready():
             break
@@ -50,7 +54,9 @@ def test_multiping(swh_app, celery_session_worker):
         assert ("OK (kw={'i': %s})" % i) in results
 
 
-def test_scheduler_fixture(swh_app, celery_session_worker, swh_scheduler):
+def test_scheduler_fixture(
+    swh_scheduler_celery_app, swh_scheduler_celery_worker, swh_scheduler
+):
     "Test that the scheduler fixture works properly"
     task_type = swh_scheduler.get_task_type("swh-test-ping")
 
@@ -59,35 +65,39 @@ def test_scheduler_fixture(swh_app, celery_session_worker, swh_scheduler):
 
     swh_scheduler.create_tasks([create_task_dict("swh-test-ping", "oneshot")])
 
-    backend_tasks = run_ready_tasks(swh_scheduler, swh_app)
+    backend_tasks = run_ready_tasks(swh_scheduler, swh_scheduler_celery_app)
     assert backend_tasks
     for task in backend_tasks:
         # Make sure the task completed
         AsyncResult(id=task["backend_id"]).get()
 
 
-def test_task_return_value(swh_app, celery_session_worker, swh_scheduler):
+def test_task_return_value(
+    swh_scheduler_celery_app, swh_scheduler_celery_worker, swh_scheduler
+):
     task_type = swh_scheduler.get_task_type("swh-test-add")
     assert task_type
     assert task_type["backend_name"] == "swh.scheduler.tests.tasks.add"
 
     swh_scheduler.create_tasks([create_task_dict("swh-test-add", "oneshot", 12, 30)])
 
-    backend_tasks = run_ready_tasks(swh_scheduler, swh_app)
+    backend_tasks = run_ready_tasks(swh_scheduler, swh_scheduler_celery_app)
     assert len(backend_tasks) == 1
     task = backend_tasks[0]
     value = AsyncResult(id=task["backend_id"]).get()
     assert value == 42
 
 
-def test_task_exception(swh_app, celery_session_worker, swh_scheduler):
+def test_task_exception(
+    swh_scheduler_celery_app, swh_scheduler_celery_worker, swh_scheduler
+):
     task_type = swh_scheduler.get_task_type("swh-test-error")
     assert task_type
     assert task_type["backend_name"] == "swh.scheduler.tests.tasks.error"
 
     swh_scheduler.create_tasks([create_task_dict("swh-test-error", "oneshot")])
 
-    backend_tasks = run_ready_tasks(swh_scheduler, swh_app)
+    backend_tasks = run_ready_tasks(swh_scheduler, swh_scheduler_celery_app)
     assert len(backend_tasks) == 1
 
     task = backend_tasks[0]
@@ -96,11 +106,11 @@ def test_task_exception(swh_app, celery_session_worker, swh_scheduler):
         result.get()
 
 
-def test_statsd(swh_app, celery_session_worker, mocker):
+def test_statsd(swh_scheduler_celery_app, swh_scheduler_celery_worker, mocker):
     m = mocker.patch("swh.scheduler.task.Statsd._send_to_server")
     mocker.patch("swh.scheduler.task.ts", side_effect=count())
     mocker.patch("swh.core.statsd.monotonic", side_effect=count())
-    res = swh_app.send_task("swh.scheduler.tests.tasks.echo")
+    res = swh_scheduler_celery_app.send_task("swh.scheduler.tests.tasks.echo")
     assert res
     res.wait()
     assert res.successful()
@@ -129,11 +139,13 @@ def test_statsd(swh_app, celery_session_worker, mocker):
     )
 
 
-def test_statsd_with_status(swh_app, celery_session_worker, mocker):
+def test_statsd_with_status(
+    swh_scheduler_celery_app, swh_scheduler_celery_worker, mocker
+):
     m = mocker.patch("swh.scheduler.task.Statsd._send_to_server")
     mocker.patch("swh.scheduler.task.ts", side_effect=count())
     mocker.patch("swh.core.statsd.monotonic", side_effect=count())
-    res = swh_app.send_task(
+    res = swh_scheduler_celery_app.send_task(
         "swh.scheduler.tests.tasks.echo", kwargs={"status": "eventful"}
     )
     assert res
